#pagehelp, #pagehelp-closed {
	font-size:12px;
	position:absolute;
	right:0; top: 150px;
	width: 200px;
	border:2px solid #ccf;
	border-right:none;
	border-bottom:none;
	background: #f2f2f7;
	color: #334;
	max-height:300px;
	overflow:auto;
	opacity:.8;
}
#pagehelp-top {
	color:#fff;
	background: #889;
	font-size:.8em;
	padding:.5em;
}
#pagehelp-top strong {
	font-size:1.2em;
	text-transform:uppercase;
}
#pagehelp-top a {
	color:#fff;
	float:right;
}
.pagehelp-content {
	padding:.5em 1em 0;
}
#pagehelp-bottom {
	font-size:.8em;
	padding:.5em;
	background: #ccf;
	text-align:center;
	zoom:1;
	overflow:hidden;
}
#pagehelp-bottom input {
	font-size:9px;
	padding:0;
	background:#ccf;
	color:#556;
	border:none;
}
#pagehelp-bottom input:hover {
	cursor:pointer;
	text-decoration:underline;
}
#pagehelp h1, #pagehelp h2 {
	padding:.25em 0;
	margin:0;
	font-size:1.5em;
	font-weight:bold;
	color:#334;
	background:none;
}
#pagehelp h2 {
	font-size:1.25em;
}
#pagehelp p, #pagehelp ul {
	padding-top:0;
	padding-bottom:1em;
	margin-top:0;
	margin-bottom:0;
}
#pagehelp ul {
	padding-left:0;
	margin-left:2em;
}
#pagehelp form,
#pagehelp-closed form {
	padding:0;
	margin:0;
}

#pagehelp-closed {
	font-size:14px;
	width:auto;
	border:none;
	line-height:1em;
	padding:0;
	overflow:hidden;
}
#pagehelp-closed .pagehelp-content,
#pagehelp-closed a {
	background:#ccf;
	padding:.5em;
	display:block;
	color:#333;
	font-weight:bold;
	opacity:.5;
	text-decoration:none;
}
#pagehelp-closed a:hover {
	opacity:1;
	color:#001;
}
#pagehelp-closed strong {
	font-style:normal;
	display:block;
}
#pagehelp-closed span {
 	font-size:9px;
 	display:block;
 	line-height:9px;
}
#pagehelp-closed form,
#pagehelp-closed .button {
	background:#aae;
}
#pagehelp-closed .button {
	display:block;
	padding:.25em 0;
	margin:0;
	width:100%;
	font-size:12px;
	color:#000;
	border:none;
}
.pagehelp-hidden {
	display:none;
}
.pagehelp-hide-page {
	float:right;
}
.pagehelp-hide-default,.pagehelp-show-default {
	float:left;
}